@@ -229,7 +229,7 @@ describe('rtpmap', () => {
 
     it('parses numChannels and defaults to 1 if not present', () => {
       expect(SDPUtils.parseRtpMap('a=rtpmap:0 PCMU/8000').numChannels)
-          .to.equal(1);
+        .to.equal(1);
     });
   });
 
@@ -302,8 +302,8 @@ describe('parseRtpEncodingParameters', () => {
   describe('bandwidth modifier', () => {
     it('of type AS is parsed', () => {
       sections = SDPUtils.splitSections(
-          videoSDP.replace('c=IN IP4 0.0.0.0\r\n',
-                           'c=IN IP4 0.0.0.0\r\nb=AS:512\r\n')
+        videoSDP.replace('c=IN IP4 0.0.0.0\r\n',
+          'c=IN IP4 0.0.0.0\r\nb=AS:512\r\n')
       );
       data = SDPUtils.parseRtpEncodingParameters(sections[1]);
 
@@ -313,8 +313,8 @@ describe('parseRtpEncodingParameters', () => {
 
     it('of type TIAS is parsed', () => {
       sections = SDPUtils.splitSections(
-          videoSDP.replace('c=IN IP4 0.0.0.0\r\n',
-                           'c=IN IP4 0.0.0.0\r\nb=TIAS:512000\r\n')
+        videoSDP.replace('c=IN IP4 0.0.0.0\r\n',
+          'c=IN IP4 0.0.0.0\r\nb=TIAS:512000\r\n')
       );
       data = SDPUtils.parseRtpEncodingParameters(sections[1]);
       expect(data[0].maxBitrate).to.equal(512000);
@@ -322,8 +322,8 @@ describe('parseRtpEncodingParameters', () => {
 
     it('of unknown type is ignored', () => {
       sections = SDPUtils.splitSections(
-          videoSDP.replace('c=IN IP4 0.0.0.0\r\n',
-                           'c=IN IP4 0.0.0.0\r\nb=something:1\r\n')
+        videoSDP.replace('c=IN IP4 0.0.0.0\r\n',
+          'c=IN IP4 0.0.0.0\r\nb=something:1\r\n')
       );
       data = SDPUtils.parseRtpEncodingParameters(sections[1]);
       expect(data[0].maxBitrate).to.equal(undefined);
@@ -508,8 +508,8 @@ describe('getDtlsParameters', () => {
 describe('writeDtlsParameters', () => {
   const type = 'actpass';
   const parameters = {fingerprints: [
-     {algorithm: 'sha-256', value: 'so:me:th:in:g1'},
-     {algorithm: 'SHA-1', value: 'somethingelse'}
+    {algorithm: 'sha-256', value: 'so:me:th:in:g1'},
+    {algorithm: 'SHA-1', value: 'somethingelse'}
   ]};
 
   const serialized = SDPUtils.writeDtlsParameters(parameters, type);
@@ -601,7 +601,7 @@ describe('extmap', () => {
   describe('writeExtmap', () => {
     it('writes extmap without direction', () => {
       expect(SDPUtils.writeExtmap({id: 1, uri: 'uri'}))
-          .to.equal('a=extmap:1 uri\r\n');
+        .to.equal('a=extmap:1 uri\r\n');
     });
 
     it('writes extmap without direction when direction is ' +
@@ -613,12 +613,12 @@ describe('extmap', () => {
 
     it('writes extmap with direction when direction is not sendrecv', () => {
       expect(SDPUtils.writeExtmap({id: 1, uri: 'uri', direction: 'sendonly'}))
-          .to.equal('a=extmap:1/sendonly uri\r\n');
+        .to.equal('a=extmap:1/sendonly uri\r\n');
     });
 
     it('writes extmap with preferredId when id is not present', () => {
       expect(SDPUtils.writeExtmap({preferredId: 1, uri: 'uri'}))
-          .to.equal('a=extmap:1 uri\r\n');
+        .to.equal('a=extmap:1 uri\r\n');
     });
   });
 });
@@ -688,7 +688,7 @@ describe('ice candidate', () => {
 
     it('parses the candidate with the legacy a= prefix', () => {
       expect(SDPUtils.parseCandidate('a=' + candidateString).foundation)
-          .to.equal('702786350');
+        .to.equal('702786350');
     });
   });
 
@@ -832,6 +832,110 @@ describe('writeRtpDescription', () => {
   });
 });
 
+describe('sctp', () => {
+  const oldSDP =
+    'm=application 63743 DTLS/SCTP 5000\r\n' +
+    'a=sctpmap:5000 webrtc-datachannel 256\r\n';
+
+  const parsedOld = SDPUtils.parseSctpDescription(oldSDP);
+  describe('parsing old form', () => {
+    it('parses port', () => {
+      expect(parsedOld.port).to.equal(5000);
+    });
+
+    it('parses protocol', () => {
+      expect(parsedOld.protocol).to.equal('webrtc-datachannel');
+    });
+
+    it('default max message size', () => {
+      expect(parsedOld.maxMessageSize).to.equal(65536);
+    });
+  });
+
+  const newSDP =
+    'm=application 54111 UDP/DTLS/SCTP webrtc-datachannel\r\n' +
+    'a=sctp-port:5000\r\n' +
+    'a=max-message-size:1024\r\n';
+  const parsedNew = SDPUtils.parseSctpDescription(newSDP);
+  describe('parsing new form', () => {
+    it('parses port', () => {
+      expect(parsedNew.port).to.equal(5000);
+    });
+
+    it('parsed protocol from m-line', () => {
+      expect(parsedNew.protocol).to.equal('webrtc-datachannel');
+    });
+
+    it('parsed max message size', () => {
+      expect(parsedNew.maxMessageSize).to.equal(1024);
+    });
+  });
+});
+
+describe('writeSctpDescription', () => {
+  let parameters;
+  let media = {
+    kind: 'application',
+    protocol: 'UDP/DTLS/SCTP'
+  };
+  beforeEach(() => {
+    parameters = {
+      protocol: 'webrtc-datachannel',
+      port: 5000,
+      maxMessageSize: 1024
+    };
+  });
+
+  it('generates correct m line', () => {
+    const serialized = SDPUtils.writeSctpDescription(media, parameters);
+    expect(serialized).to.contain(
+      'm=application 9 UDP/DTLS/SCTP webrtc-datachannel'
+    );
+  });
+
+  it('generates sctp-port lines', () => {
+    const serialized = SDPUtils.writeSctpDescription(media, parameters);
+    expect(serialized).to.contain('a=sctp-port:5000');
+  });
+
+  it('generates max-message-size lines', () => {
+    const serialized = SDPUtils.writeSctpDescription(media, parameters);
+    expect(serialized).to.contain('a=max-message-size:1024');
+  });
+});
+
+describe('writeSctpDescription (old format answer)', () => {
+  let parameters;
+  let media = {
+    kind: 'application',
+    protocol: 'DTLS/SCTP'
+  };
+  beforeEach(() => {
+    parameters = {
+      protocol: 'webrtc-datachannel',
+      port: 5000,
+      maxMessageSize: 1024
+    };
+  });
+
+  it('generates correct m line', () => {
+    const serialized = SDPUtils.writeSctpDescription(media, parameters);
+    expect(serialized).to.contain(
+      'm=application 9 DTLS/SCTP 5000'
+    );
+  });
+
+  it('generates sctpmap lines', () => {
+    const serialized = SDPUtils.writeSctpDescription(media, parameters);
+    expect(serialized).to.contain('a=sctpmap:5000 webrtc-datachannel 65535');
+  });
+
+  it('generates max-message-size lines', () => {
+    const serialized = SDPUtils.writeSctpDescription(media, parameters);
+    expect(serialized).to.contain('a=max-message-size:1024');
+  });
+});
+
 describe('writeBoilerPlate', () => {
   let sdp;
   beforeEach(() => {
